@@ -33,9 +33,10 @@
 #  define KPEOPLE_DEPRECATED_NO_EXPORT KPEOPLE_NO_EXPORT KPEOPLE_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KPEOPLE_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KPEOPLE_NO_DEPRECATED
+#    define KPEOPLE_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
