@@ -33,9 +33,10 @@
 #  define KPEOPLEWIDGETS_DEPRECATED_NO_EXPORT KPEOPLEWIDGETS_NO_EXPORT KPEOPLEWIDGETS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KPEOPLEWIDGETS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KPEOPLEWIDGETS_NO_DEPRECATED
+#    define KPEOPLEWIDGETS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
