@@ -33,9 +33,10 @@
 #  define KPEOPLEBACKEND_DEPRECATED_NO_EXPORT KPEOPLEBACKEND_NO_EXPORT KPEOPLEBACKEND_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KPEOPLEBACKEND_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KPEOPLEBACKEND_NO_DEPRECATED
+#    define KPEOPLEBACKEND_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
